package org.apache.bcel.classfile;

import java.io.DataInput;
import java.io.DataOutputStream;
import java.io.IOException;
import org.apache.bcel.Const;

public final class Deprecated extends Attribute {
   private byte[] bytes;

   public Deprecated(Deprecated c) {
      this(c.getNameIndex(), c.getLength(), c.getBytes(), c.getConstantPool());
   }

   public Deprecated(int nameIndex, int length, byte[] bytes, ConstantPool constantPool) {
      super((byte)8, nameIndex, length, constantPool);
      this.bytes = bytes;
   }

   Deprecated(int nameIndex, int length, DataInput input, ConstantPool constantPool) throws IOException {
      this(nameIndex, length, (byte[])null, constantPool);
      if (length > 0) {
         this.bytes = new byte[length];
         input.readFully(this.bytes);
         println("Deprecated attribute with length > 0");
      }

   }

   public void accept(Visitor v) {
      v.visitDeprecated(this);
   }

   public Attribute copy(ConstantPool constantPool) {
      Deprecated c = (Deprecated)this.clone();
      if (this.bytes != null) {
         c.bytes = (byte[])this.bytes.clone();
      }

      c.setConstantPool(constantPool);
      return c;
   }

   public void dump(DataOutputStream file) throws IOException {
      super.dump(file);
      if (super.getLength() > 0) {
         file.write(this.bytes, 0, super.getLength());
      }

   }

   public byte[] getBytes() {
      return this.bytes;
   }

   public void setBytes(byte[] bytes) {
      this.bytes = bytes;
   }

   public String toString() {
      return Const.getAttributeName(8) + ": true";
   }
}
